@@ -1,6 +1,6 @@
 
 #include "optionssimple.h"
-#include "config.h"
+#include "configuration.h"
 #include "convertpluginloader.h"
 #include "optionsdetailed.h"
 
@@ -51,11 +51,11 @@ OptionsSimple::OptionsSimple( Config* _config, OptionsDetailed* _optionsDetailed
     sProfile += i18n("User defined");
     cProfile->insertStringList( sProfile );
     topBox->addWidget( cProfile, 0, TQt::AlignVCenter );
-    connect( cProfile, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(profileChanged())
+    connect( cProfile, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(profileChanged())
              );
-    connect( cProfile, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(somethingChanged())
+    connect( cProfile, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(somethingChanged())
              );
     topBox->addSpacing( 3 );
     //pProfileRemove = new TDEToolBarButton( "edit-delete", 1002, this, "pProfileRemove" );
@@ -63,15 +63,15 @@ OptionsSimple::OptionsSimple( Config* _config, OptionsDetailed* _optionsDetailed
     pProfileRemove->hide();
     TQToolTip::add( pProfileRemove, i18n("Remove the selected profile") );
     topBox->addWidget( pProfileRemove, 0, TQt::AlignVCenter );
-    connect( pProfileRemove, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(profileRemove())
+    connect( pProfileRemove, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(profileRemove())
              );
     //pProfileInfo = new TDEToolBarButton( "messagebox_info", 1110, this, "pProfileInfo" );
     pProfileInfo = new KPushButton( iconLoader->loadIcon("messagebox_info",TDEIcon::Small), i18n("Info"), this, "pProfileInfo" );
     TQToolTip::add( pProfileInfo, i18n("Information about the selected profile") );
     topBox->addWidget( pProfileInfo, 0, TQt::AlignVCenter );
-    connect( pProfileInfo, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(profileInfo())
+    connect( pProfileInfo, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(profileInfo())
              );
     topBox->addSpacing( 18 );
 
@@ -79,19 +79,19 @@ OptionsSimple::OptionsSimple( Config* _config, OptionsDetailed* _optionsDetailed
     topBox->addWidget( lFormat, 0, TQt::AlignVCenter );
     cFormat = new KComboBox( this, "cFormat" );
     topBox->addWidget( cFormat, 0, TQt::AlignVCenter );
-    connect( cFormat, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(formatChanged())
+    connect( cFormat, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(formatChanged())
              );
-    connect( cFormat, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(somethingChanged())
+    connect( cFormat, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(somethingChanged())
              );
     topBox->addSpacing( 3 );
     //pFormatInfo = new TDEToolBarButton( "messagebox_info", 1111, this, "pFormatInfo" );
     pFormatInfo = new KPushButton( iconLoader->loadIcon("messagebox_info",TDEIcon::Small), i18n("Info"), this, "pFormatInfo" );
     TQToolTip::add( pFormatInfo, i18n("Information about the selected file format") );
     topBox->addWidget( pFormatInfo, 0, TQt::AlignVCenter );
-    connect( pFormatInfo, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(formatInfo())
+    connect( pFormatInfo, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(formatInfo())
              );
     topBox->addStretch( );
 
@@ -100,17 +100,17 @@ OptionsSimple::OptionsSimple( Config* _config, OptionsDetailed* _optionsDetailed
 
     outputDirectory = new OutputDirectory( config, this, "outputDirectory" );
     middleBox->addWidget( outputDirectory, 0, TQt::AlignVCenter );
-    connect( outputDirectory, TQT_SIGNAL(modeChanged(OutputDirectory::Mode)),
-               this, TQT_SLOT(outputDirectoryModeChanged(OutputDirectory::Mode))
+    connect( outputDirectory, TQ_SIGNAL(modeChanged(OutputDirectory::Mode)),
+               this, TQ_SLOT(outputDirectoryModeChanged(OutputDirectory::Mode))
              );
-    connect( outputDirectory, TQT_SIGNAL(directoryChanged(const TQString&)),
-               this, TQT_SLOT(outputDirectoryPathChanged(const TQString&))
+    connect( outputDirectory, TQ_SIGNAL(directoryChanged(const TQString&)),
+               this, TQ_SLOT(outputDirectoryPathChanged(const TQString&))
              );
-    connect( outputDirectory, TQT_SIGNAL(modeChanged(OutputDirectory::Mode)),
-               this, TQT_SLOT(somethingChanged())
+    connect( outputDirectory, TQ_SIGNAL(modeChanged(OutputDirectory::Mode)),
+               this, TQ_SLOT(somethingChanged())
              );
-    connect( outputDirectory, TQT_SIGNAL(directoryChanged(const TQString&)),
-               this, TQT_SLOT(somethingChanged())
+    connect( outputDirectory, TQ_SIGNAL(directoryChanged(const TQString&)),
+               this, TQ_SLOT(somethingChanged())
              );
 
     TQHBoxLayout *bottomBox = new TQHBoxLayout( );
@@ -572,3 +572,4 @@ void OptionsSimple::refill()
     outputDirectory->setDirectory( optionsDetailed->getOutputDirectoryPath() );
 }
 
+#include "optionssimple.moc"
